@@ -1,5 +1,5 @@
 package Test::MockObject;
-$Test::MockObject::VERSION = '1.20150521';
+$Test::MockObject::VERSION = '1.20150527';
 use strict;
 use warnings;
 
@@ -9,8 +9,14 @@ sub import
 {
     my $self = shift;
     return unless grep /^-debug/, @_;
-    eval "use UNIVERSAL::isa 'verbose'";
-    eval "use UNIVERSAL::can '-always_warn'";
+    eval {
+	require UNIVERSAL::isa;
+	UNIVERSAL::isa::->import('verbose');
+    };
+    eval {
+	require UNIVERSAL::can;
+	UNIVERSAL::can::->import('-always_warn');
+    };
 }
 
 use Test::Builder;
