@@ -1,16 +1,13 @@
 package Test::MockObject::Extends;
-$Test::MockObject::Extends::VERSION = '1.20150521';
+$Test::MockObject::Extends::VERSION = '1.20150527';
 use strict;
 use warnings;
 
 use Test::MockObject;
 
-sub import
-{
-    my $self = shift;
-    eval "use Test::MockObject";
-    Test::MockObject->import( @_ );
-}
+# Alias our 'import' to T:MO::import to handle this:
+#    use Test::MockObject::Extends '-debug';
+*import = \&Test::MockObject::import;
 
 use Devel::Peek  'CvGV';
 use Scalar::Util 'blessed';
